### Description

[Description of the bug or feature]

### Steps to Reproduce

1. [First Step]
2. [Second Step]
3. [and so on...]

### Expected behavior:

[What you expected to happen]

### Actual behavior

[What actually happened]

### Versions

You can get this information from executing `caso --version`.
